#!/bin/sh
# *******************************************************************************
#  Materiales bajo licencia - Propiedad de IBM
#  (c) Copyright IBM Corporation 2012, 2016. Reservados todos los derechos.

#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in 

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "No ejecute el script app_upgrade directamente. Para actualizar una aplicación, ejecute uno de estos mandatos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilice -help para obtener una descripción completa de los mandatos anteriores."
;;

INVALID_START_DIR )
echo ""
echo "Salvo cuando se utiliza el parámetro -help, el script $2 no se puede ejecutar desde ningún directorio que no sea $3"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "El archivo '$2' contiene los valores de parámetro del script de actualización."
echo "Si necesita modificar alguno de los valores de parámetro predeterminados, puede editar estos archivos o puede especificar los valores de parámetro como argumentos de línea de mandatos en los scripts de actualización."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "El siguiente conjunto de archivos contiene valores de parámetro predeterminados para una actualización de aplicación. Si necesita modificar alguno de los valores de parámetro predeterminados, puede editar estos archivos o puede especificar los valores de parámetro como argumentos de línea de mandatos en los scripts de actualización."
echo "- Actualización de DM:   $2/params/dm_params$3.sh"
echo "- Actualización de VVC:  $2/params/vvc_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "No se ha especificado ningún tipo de aplicación. Para actualizar la aplicación, ejecute uno de estos mandatos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilice -help para obtener una descripción completa de los mandatos anteriores."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 no es un tipo de aplicación válido. Para actualizar la aplicación, ejecute uno de estos mandatos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilice -help para obtener una descripción completa de los mandatos anteriores."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Falta un valor para el parámetro $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "El directorio $3 especificado para el parámetro $2 no existe o no es válido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "El directorio $3 especificado para el parámetro $2 debe ser una vía de acceso absoluta. "
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "El archivo $3 especificado para el parámetro $2 no existe o no es válido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 es un valor no válido para el parámetro $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 es un parámetro desconocido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Falta el parámetro $2 del directorio de inicio."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "El directorio $2 no existe o no es válido."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "No se puede encontrar el mandato repotools de aplicación '$2'."
echo ""
echo "Compruebe que el parámetro -oldApplicationHome '$3' apunta al directorio de configuración de servidor antiguo; por ejemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parámetro -oldApplicationHome '$3' apunta al directorio de configuración de servidor antiguo, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro -oldApplicationHome '$3' apunta al directorio de configuración de servidor antiguo; por ejemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro -oldApplicationHome '$3' apunta al directorio de configuración de servidor antiguo, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parámetro -newApplicationHome '$3' apunta al nuevo directorio de configuración del servidor de aplicaciones, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo "Si va a realizar una actualización desde un release anterior, asegúrese de que ha seleccionado las raíces de contexto correctas.  Por ejemplo, si utiliza Gestor de instalación, debe seleccionar la opción de raíz de contexto $5 en el panel "Opciones de raíz de contexto". Si ha seleccionado por accidente una opción diferente, debe volver a instalar el producto con la opción de raíz de contexto $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro -newApplicationHome '$3' apunta al nuevo directorio de configuración del servidor JTS, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo "Si va a realizar una actualización desde un release anterior, asegúrese de que ha seleccionado las raíces de contexto correctas.  Por ejemplo, si utiliza Gestor de instalación, debe seleccionar la opción de raíz de contexto $5 en el panel "Opciones de raíz de contexto". Si ha seleccionado por accidente una opción diferente, debe volver a instalar el producto con la opción de raíz de contexto $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parámetro -oldJTSHome '$3' apunta al directorio de configuración del servidor JTS antiguo, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro -oldJTSHome '$3' apunta al directorio de configuración del servidor JTS antiguo, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parámetro -newJTSHome '$3' apunta al nuevo directorio de configuración del servidor JTS, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro -newJTSHome '$3' apunta al nuevo directorio de configuración del servidor JTS, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Falta el archivo tar que contiene los datos de la versión 2.x necesarios para actualizar $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_dm )
echo ""
echo ""
echo "============================================="
echo "===    Actualización de DM    ==="
echo "============================================="
echo ""
;;

BANNER_vvc )
echo ""
echo ""
echo "============================================"
echo "===    Actualización de VVC    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "La última ejecución falló en el paso inicial..."
;;

LAST_STEP_FAILED )
echo ""
echo "La última ejecución falló en el paso $2..."
echo "¿Desea reiniciar la actualización desde este paso o desde otro anterior?"
;;

ALREADY_RUN )
echo ""
echo "La actualización se ha realizado y ha finalizado satisfactoriamente..."
echo "¿Desea iniciar una nueva a partir de un determinado paso?"
;;

LAST_STEP_PASSED )
echo ""
echo "La última ejecución se detuvo satisfactoriamente en el paso $2..."
echo "¿Desea reiniciar la actualización desde el paso $3 actual o desde otro anterior?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Especifique el número de paso [$2-$3] desde el que desee reiniciar la actualización o pulse la tecla [Intro] para cancelar:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' no es un número. Especifique un número de paso válido."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' no es un número de paso válido. Especifique un número de paso válido."
;;

MAX_STEP_NUMBER )
echo ""
echo "El último paso es $2; por lo tanto, no podrá reiniciar la actualización en el paso $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "El paso $2 no se ha ejecutado todavía; por lo tanto, no podrá reiniciar la actualización en el paso $3."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Paso 0: descartar tablas"
echo "------------------------"
;;

STEP_0 )
echo "Paso 0: Actualizar archivos de configuración"
echo "--------------------------------------------"
;;

STEP_1_ADD )
echo "Paso 1: Añadir tablas"
echo "---------------------"
;;

STEP_2_FIX_VERSION_TABLE )
echo "Paso 2: Corregir tablas de versión"
echo "----------------------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Paso $2: Volver a crear índices de texto"
echo "----------------------------------------"
;;

JFS_INDICES_STEP )
echo "Paso $2: Volver a crear índices de consulta y de búsqueda"
echo "---------------------------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Paso 2: Actualizar el esquema de depósito de datos"
echo "--------------------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "La actualización $2 falló en el paso $3.  Corrija el problema y vuelva a ejecutar el script comenzando por el paso $3."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_DM )
echo ""
echo "La actualización de $2 ha sido satisfactoria. Si también a actualizado JTS, puede iniciar ahora los servidores en el despliegue."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_VVC )
echo ""
echo "La actualización de $2 ha sido satisfactoria. Si también ha actualizado JTS y cualquier aplicación dependiente (como DM), ahora puede iniciar los servidores en el despliegue."
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Directorio: $2"
echo "Mandato:"
;;

ENTER_STEP_ACTION )
echo "Especifique [E] para ejecutar este paso, [S] para omitirlo o pulse [Intro] para cancelar la ejecución del script:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' no es una entrada válida; solo se permiten 'E', 'S' o 'Intro'"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Se abrirá un editor vi para permitirle verificar el archivo teamserver.properties de $2."
echo "Verifique que la raíz del URI público indicada por la propiedad com.ibm.team.repository.server.webapp.url es correcta."
echo "Verifique que las propiedades de la base de datos son correctas."
echo "Cuando haya finalizado, guarde los cambios, si hay alguno, y cierre el editor para continuar ejecutando el script."
echo ""
;;

PAUSE )
echo ""
echo "Escriba [C] para proseguir la ejecución o pulse [Intro] para cancelar la ejecución del script:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' no es una entrada válida; solo se permiten 'C' o 'Intro'"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "No se han podido copiar los índices de '$2' a '$3'."
echo "Compruebe la propiedad com.ibm.team.fulltext.indexLocation"
echo "definida en el archivo teamserver.properties."
echo "Copie manualmente los índices de texto en este directorio"
echo "o ejecute repotools -rebuildTextIndices para volver a crearlos."
echo ""
;;

COPY_TRS_DB_FAILED )
echo ""
echo "No se ha podido copiar la base de datos TRS de '$2' a '$3'."
echo "Compruebe la propiedad com.ibm.xtools.trs.database"
echo "definida en el archivo teamserver.properties."
echo "Copie manualmente la jerarquía del directorio de bases de datos TRS."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "No hay ningún URI público definido en"
echo "$3,"
echo "por lo que no se puede iniciar la actualización."
echo ""
echo "Debe haber un URI público en este archivo definido de la forma siguiente:"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propiedad del URI público com.ibm.team.repository.server.webapp.url debe estar presente en el archivo teamserver.properties."
echo "Añada la propiedad al archivo teamserver.properties de la instalación anterior y establezca el valor para que sea la raíz de URI que utilicen todos los clientes para localizar el servidor."
echo "La raíz de URI público es esencial para un funcionamiento correcto de la nueva instalación. La actualización no se realizará correctamente sin esta propiedad. "
echo "Para obtener más información, consulte el tema del InfoCenter sobre 'Planificación de sus URI'."
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Todos los URI públicos definidos en"
echo "$3,"
echo "se han comentado, por lo tanto, no se puede iniciar la actualización."
echo ""
echo "Debe haber un URI público sin comentar en este archivo definido del siguiente modo:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propiedad del URI público com.ibm.team.repository.server.webapp.url debe estar presente en el archivo teamserver.properties."
echo "Añada la propiedad al archivo teamserver.properties de la instalación anterior y establezca el valor para que sea la raíz de URI que utilicen todos los clientes para localizar el servidor."
echo "La raíz de URI público es esencial para un funcionamiento correcto de la nueva instalación. La actualización no se realizará correctamente sin esta propiedad."
echo "Para obtener más información, consulte el tema del InfoCenter sobre 'Planificación de sus URI'."
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "La raíz de contexto para JTS se ha establecido en '$2'."
echo "La raíz de contexto para la aplicación se ha establecido en '$3'."
echo "La raíz de contexto para jts y la aplicación no puede ser la misma."
echo ""
;;

esac

}
